VacantEntry

Struct VacantEntry 

pub struct VacantEntry<'a, K: Ord, V, const N: usize> { /* private fields */ }
A view into a vacant entry in a SgMap. It is part of the Entry enum.

Implementations

Source

impl<'a, K: Ord, V, const N: usize> VacantEntry<'a, K, V, N>

pub fn key(&self) -> &K

Gets a reference to the key that would be used when inserting a value through the VacantEntry.

Examples
use escapegoat::SgMap;

let mut map = SgMap::<&str, usize, 2>::new();
assert_eq!(map.entry("poneyland").key(), &"poneyland");
pub fn into_key(self) -> K

Take ownership of the key.

Examples
use escapegoat::SgMap;
use escapegoat::map_types::Entry;

let mut map = SgMap::<&str, usize, 2>::new();

if let Entry::Vacant(v) = map.entry("poneyland") {
    v.into_key();
}
pub fn insert(self, value: V) -> &'a mut V

Sets the value of the entry with the VacantEntry’s key, and returns a mutable reference to it.

Examples
use escapegoat::SgMap;
use escapegoat::map_types::Entry;

let mut map = SgMap::<&str, u32, 2>::new();

if let Entry::Vacant(o) = map.entry("poneyland") {
    o.insert(37);
}
assert_eq!(map["poneyland"], 37);