pub struct VacantEntry<'a, K: Ord, V, const N: usize> { /* private fields */ }Implementations
Sourceimpl<'a, K: Ord, V, const N: usize> VacantEntry<'a, K, V, N>
impl<'a, K: Ord, V, const N: usize> VacantEntry<'a, K, V, N>
Sourcepub fn key(&self) -> &K
pub fn key(&self) -> &K
Gets a reference to the key that would be used when inserting a value
through the VacantEntry.
Examples
use escapegoat::SgMap;
let mut map = SgMap::<&str, usize, 2>::new();
assert_eq!(map.entry("poneyland").key(), &"poneyland");Sourcepub fn into_key(self) -> K
pub fn into_key(self) -> K
Take ownership of the key.
Examples
use escapegoat::SgMap;
use escapegoat::map_types::Entry;
let mut map = SgMap::<&str, usize, 2>::new();
if let Entry::Vacant(v) = map.entry("poneyland") {
v.into_key();
}Sourcepub fn insert(self, value: V) -> &'a mut V
pub fn insert(self, value: V) -> &'a mut V
Sets the value of the entry with the VacantEntry’s key,
and returns a mutable reference to it.
Examples
use escapegoat::SgMap;
use escapegoat::map_types::Entry;
let mut map = SgMap::<&str, u32, 2>::new();
if let Entry::Vacant(o) = map.entry("poneyland") {
o.insert(37);
}
assert_eq!(map["poneyland"], 37);Auto Trait Implementations
impl<'a, K, V, const N: usize> !UnwindSafe for VacantEntry<'a, K, V, N>
impl<'a, K, V, const N: usize> Freeze for VacantEntry<'a, K, V, N>where
K: Freeze,
impl<'a, K, V, const N: usize> RefUnwindSafe for VacantEntry<'a, K, V, N>where
K: RefUnwindSafe,
V: RefUnwindSafe,
impl<'a, K, V, const N: usize> Send for VacantEntry<'a, K, V, N>
impl<'a, K, V, const N: usize> Sync for VacantEntry<'a, K, V, N>
impl<'a, K, V, const N: usize> Unpin for VacantEntry<'a, K, V, N>where
K: Unpin,
impl<'a, K, V, const N: usize> UnsafeUnpin for VacantEntry<'a, K, V, N>where
K: UnsafeUnpin,